<?php
/*
 * Our view file.
 *
 * PHP version 5
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the Affero General Public License as published by Affero Inc.,
 * either version 1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful to the Free
 * Software community, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Affero
 * General Public License for more details.
 * 
 * You should have received a copy of the Affero General Public License with this
 * software in the ./AfferoGPL file; if not, write to Affero Inc., 510 Third Street,
 * Suite 225, San Francisco, CA 94107, USA
 *
 * @category   View Class
 * @author     Klaus Weiss <klaus.weiss@nanet.at>
 * @copyright  2007 GNU Herds Free Software Association
 * @license    http://www.affero.org/oagpl.html Affero GPL
 * @version    CVS: $Id:$
 * @since      File available since version 1.5
 */

if(!defined('VISIBLE')) exit();

class View
{
  public $name = null;

  public $layout = 'default';

  public $triggeredFormErrors = array();

  /* Html is a standard helper. */
  public $h = array('Html' => null);

  public $body_content = null;

  public $pageVars = array();

  public $cntr = null;


  public function __construct($cntr)
  {  
    $this->cntr = $cntr;

    $this->name = strtolower($cntr->name);

    if($cntr->helpers == null or !is_array($cntr->helpers))
      {
	return;
      }

    foreach($cntr->helpers as $h)
      {
	$helper = ROOT.'/../../core/view/helpers/'.$h.'.class.php';

	if(file_exists($helper))
	  {
	    require_once($helper);

	    $this->h[$h] = new $h($this);
	  }
      }
  }

  public function parseElement($eid)
  {
    $file = ROOT.'/../../site/view/elements/'.$eid.'.html';

    if(file_exists($file))
      {
	ob_start();
	extract($this->pageVars);
	require_once($file);
	$element_content = ob_get_contents();
	ob_end_clean();
      }

    return $element_content;
  }

  public function render($action)
  {
    $file = ROOT.'/../../site/view/view/'.$this->name.'/'.$action.'.html';

    if(!file_exists($file))
      {
	show_error_site(ERROR_NO_VIEW);
      }

    ob_start();
    extract($this->pageVars);
    require_once($file);
    $this->body_content = ob_get_contents();
    ob_end_clean();

    if($this->layout != null)
      {
	$layout = ROOT.'/../../site/view/layouts/'.$this->layout.'.html';
	
	if(!file_exists($layout))
	  {
	    $layout_content = null;
	  }
	else
	  {
	    ob_start();
	    require_once($layout);
	    $layout_content = ob_get_contents();
	    ob_end_clean();
	  }
	
	if(!empty($layout_content))
	  {
	    echo $layout_content;
	  }
	else
	  {
	    echo $this->body_content;
	  }	
      }
    else
      {
	echo $this->body_content;
      }
  }

  public function triggerFormError($model, $text, $type = null)
  {
    $this->triggeredFormErrors[$model] = $text;
  }
}

?>
